@@ -156,14 +156,14 @@ impl Library {
             .iter()
             .position(|i| i.id == id);
 
-        if let Some(position) = position {
-            if self.spotify.api.delete_playlist(id).is_ok() {
-                self.playlists.write().unwrap().remove(position);
-                self.save_cache(
-                    &config::cache_path(CACHE_PLAYLISTS),
-                    &self.playlists.read().unwrap(),
-                );
-            }
+        if let Some(position) = position
+            && self.spotify.api.delete_playlist(id).is_ok()
+        {
+            self.playlists.write().unwrap().remove(position);
+            self.save_cache(
+                &config::cache_path(CACHE_PLAYLISTS),
+                &self.playlists.read().unwrap(),
+            );
         }
     }
 
@@ -694,15 +694,14 @@ impl Library {
             return;
         }
 
-        if let Some(ref album_id) = album.id {
-            if self
+        if let Some(ref album_id) = album.id
+            && self
                 .spotify
                 .api
                 .current_user_saved_albums_add(vec![album_id.as_str()])
                 .is_err()
-            {
-                return;
-            }
+        {
+            return;
         }
 
         {
@@ -727,15 +726,14 @@ impl Library {
             return;
         }
 
-        if let Some(ref album_id) = album.id {
-            if self
+        if let Some(ref album_id) = album.id
+            && self
                 .spotify
                 .api
                 .current_user_saved_albums_delete(vec![album_id.as_str()])
                 .is_err()
-            {
-                return;
-            }
+        {
+            return;
         }
 
         {
@@ -765,15 +763,14 @@ impl Library {
             return;
         }
 
-        if let Some(ref artist_id) = artist.id {
-            if self
+        if let Some(ref artist_id) = artist.id
+            && self
                 .spotify
                 .api
                 .user_follow_artists(vec![artist_id.as_str()])
                 .is_err()
-            {
-                return;
-            }
+        {
+            return;
         }
 
         {
@@ -801,15 +798,14 @@ impl Library {
             return;
         }
 
-        if let Some(ref artist_id) = artist.id {
-            if self
+        if let Some(ref artist_id) = artist.id
+            && self
                 .spotify
                 .api
                 .user_unfollow_artists(vec![artist_id.as_str()])
                 .is_err()
-            {
-                return;
-            }
+        {
+            return;
         }
 
         {
