@@ -123,7 +123,7 @@ impl MprisPlayer {
     }
 
     #[zbus(property)]
-    fn metadata(&self) -> HashMap<String, Value> {
+    fn metadata(&self) -> HashMap<String, Value<'_>> {
         let mut hm = HashMap::new();
 
         let playable = self.queue.get_current();
@@ -393,17 +393,17 @@ impl MprisPlayer {
         let uri_type = spotify_url.map(|s| s.uri_type);
         match uri_type {
             Some(UriType::Album) => {
-                if let Ok(a) = self.spotify.api.album(&id) {
-                    if let Some(t) = &Album::from(&a).tracks {
-                        let should_shuffle = self.queue.get_shuffle();
-                        self.queue.clear();
-                        let index = self.queue.append_next(
-                            &t.iter()
-                                .map(|track| Playable::Track(track.clone()))
-                                .collect(),
-                        );
-                        self.queue.play(index, should_shuffle, should_shuffle)
-                    }
+                if let Ok(a) = self.spotify.api.album(&id)
+                    && let Some(t) = &Album::from(&a).tracks
+                {
+                    let should_shuffle = self.queue.get_shuffle();
+                    self.queue.clear();
+                    let index = self.queue.append_next(
+                        &t.iter()
+                            .map(|track| Playable::Track(track.clone()))
+                            .collect(),
+                    );
+                    self.queue.play(index, should_shuffle, should_shuffle)
                 }
             }
             Some(UriType::Track) => {
